import traceback
import nonebot.adapters.onebot.v11
from loguru import logger
from nonebot import get_bot, on_command, on_message, get_driver
from nonebot.params import CommandArg
from nonebot.adapters.onebot.v11 import Message, MessageSegment,MessageEvent,Bot,ActionFailed,GroupMessageEvent,PrivateMessageEvent
from nonebot_plugin_guild_patch import GuildMessageEvent
from nonebot.log import logger
from .publicAPI import get_nation_list,get_ship_name,get_ship_byName
from .wws_info import get_AccountInfo
from .wws_recent import get_RecentInfo
from .wws_bind import set_BindInfo,get_BindInfo,change_BindInfo,set_special_BindInfo,delete_BindInfo
from .wws_ship import get_ShipInfo,get_ShipInfoRecent,ShipSecletProcess
from .wws_clan import get_ClanInfo,ClanSecletProcess
from .wws_record import get_record
from .wws_shiprank import get_ShipRank
from .data_source import command_list
from .utils import find_and_replace_keywords,DailyNumberLimiter,FreqLimiter
from nonebot_plugin_htmlrender import text_to_pic
from pathlib import Path
import httpx
import json
import asyncio
import re
import html
from nonebot import require
scheduler = require("nonebot_plugin_apscheduler").scheduler

_max = 100
EXCEED_NOTICE = f'您今天已经冲过{_max}次了，请明早5点后再来！'
_nlmt = DailyNumberLimiter(_max)
_flmt = FreqLimiter(3)
__version__ = '0.3.3.1'
dir_path = Path(__file__).parent
template_path = dir_path / "template"

bot = on_command("wws", block=False, aliases={"WWS"},priority=5)
bot_listen = on_message(priority=5,block=False)
bot_checkversion = on_command("wws 检查更新",priority=5,block=False)
driver = get_driver()

@bot.handle()
async def selet_command(ev:MessageEvent, matchmsg: Message = CommandArg()):
    try:
        server_type = None
        if isinstance(ev, PrivateMessageEvent) and (driver.config.private or str(ev.user_id) in driver.config.superusers):       #私聊事件,superusers默认不受影响
            server_type = 'QQ'
        elif isinstance(ev, GroupMessageEvent) and driver.config.group and ev.group_id not in driver.config.ban_group_list:         #群聊事件
            server_type = 'QQ'
        elif isinstance(ev, GuildMessageEvent) and driver.config.channel:       #频道事件
            if driver.config.all_channel or ev.channel_id in driver.config.channel_list:
                server_type = 'QQ_CHANNEL'
            else:
                return
        else:
            return
        msg = ''
        qqid = ev.user_id
        select_command,replace_name = None,None
        if not _nlmt.check(qqid):
            await bot.send(EXCEED_NOTICE, at_sender=True)
            return
        if not _flmt.check(qqid):
            await bot.send('您冲得太快了，请稍候再冲', at_sender=True)
            return
        _flmt.start_cd(qqid)
        _nlmt.increase(qqid) 
        searchtag = html.unescape(str(matchmsg)).strip()
        if not searchtag:
            await bot.send("请发送wws help查看相关帮助")
            return
        match = re.search(r"(\(|（)(.*?)(\)|）)",searchtag)
        if match:
            replace_name = match.group(2)
            search_list = searchtag.replace(match.group(0),'').split()
        else:
            search_list = searchtag.split()
        select_command,search_list = await find_and_replace_keywords(search_list,command_list)
        if not select_command:
            if replace_name:
                search_list.append(replace_name)
            msg = await get_AccountInfo(server_type,qqid,search_list)
        elif select_command == 'ship':
            select_command = None
            select_command,search_list = await find_and_replace_keywords(search_list,command_list)         #第二次匹配
            if replace_name:
                search_list.append(replace_name)
            if not select_command:
                msg = await get_ShipInfo(server_type,qqid,search_list,bot)
            elif select_command == 'recent':
                msg = await get_ShipInfoRecent(server_type,qqid,search_list,bot)
            else:
                msg = '看不懂指令QAQ'
        elif select_command == 'recent':
            select_command = None
            select_command,search_list = await find_and_replace_keywords(search_list,command_list)             #第二次匹配
            if replace_name:
                search_list.append(replace_name)
            if not select_command:
                msg = await get_RecentInfo(server_type,qqid,search_list)
            elif select_command == 'ship':
                msg = await get_ShipInfoRecent(server_type,qqid,search_list,bot)
            else:
                msg = '看不懂指令QAQ'
        elif select_command == 'clan':
            select_command = None
            select_command,search_list = await find_and_replace_keywords(search_list,command_list) 
            if not select_command:                  #查询公会详情信息
                msg = await get_ClanInfo(server_type,qqid,search_list,bot)
            elif select_command == 'record':        #查询公会历史记录
                msg = await get_record(server_type,qqid,search_list,"clan")
        elif select_command == 'record':
            select_command = None
            select_command,search_list = await find_and_replace_keywords(search_list,command_list) 
            if replace_name:
                search_list.append(replace_name)
            if not select_command:                  #查询个人历史记录
                msg = await get_record(server_type,qqid,search_list,"personal")
            elif select_command == 'clan':          #查询公会历史记录
                msg = await get_record(server_type,qqid,search_list,"clan")
        elif select_command == 'ship_rank':
            msg = await get_ShipRank(qqid,search_list,bot)   
        elif select_command == 'bind':
            if replace_name:
                search_list.append(replace_name)
            msg = await set_BindInfo(server_type,qqid,search_list)
        elif select_command == 'special_bind':
            msg = await set_special_BindInfo(server_type,qqid,search_list)
        elif select_command == 'bindlist':
            msg = await get_BindInfo(server_type,qqid,search_list)
        elif select_command == 'changebind':
            msg = await change_BindInfo(server_type,qqid,search_list)
        elif select_command == 'delete_bind':
            msg = await delete_BindInfo(server_type,qqid,search_list)
        elif select_command == 'searchship':
            msg = await get_ship_name(search_list)
        elif select_command == 'help':
            msg = await send_bot_help()
        else:
            msg = '看不懂指令QAQ'
        if msg:
            if isinstance(msg,str):
                await bot.send(msg)
                return
            else:
                await bot.send(MessageSegment.image(msg))
                return
        else:
            await bot.send('呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')
            return
    except ActionFailed:
        logger.warning(traceback.format_exc())
        try:
            await bot.send('发不出图片，可能被风控了QAQ')
        except Exception:
            pass
        return
    except Exception:
        logger.error(traceback.format_exc())
        await bot.finish('呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')
                
async def send_bot_help():
    try:
        url = 'https://benx1n.oss-cn-beijing.aliyuncs.com/version.json'
        async with httpx.AsyncClient() as client:
            resp = await client.get(url, timeout=10)
            result = json.loads(resp.text)
        latest_version = result['latest_version']
        url = 'https://benx1n.oss-cn-beijing.aliyuncs.com/wws_help.txt'
        async with httpx.AsyncClient() as client:
            resp = await client.get(url, timeout=10)
            result = resp.text
        result = f'''帮助列表                                                当前版本{__version__}  最新版本{latest_version}\n{result}'''
        img = await text_to_pic(text = result,css_path = str(template_path/"text-help.css"), width = 800)
        return img
    except Exception:
        logger.warning(traceback.format_exc())
        return 'wuwuwu出了点问题，请联系麻麻解决'
    
@bot_listen.handle()
async def change_select_state(ev:MessageEvent):
    try:
        msg = str(ev.message)
        qqid = ev.user_id
        if ShipSecletProcess[qqid].SelectList and str(msg).isdigit():
            if int(msg) <= len( ShipSecletProcess[qqid].SelectList):
                ShipSecletProcess[qqid] = ShipSecletProcess[qqid]._replace(state = True)
                ShipSecletProcess[qqid] = ShipSecletProcess[qqid]._replace(SlectIndex = int(msg))
            else:
                await bot.send('请选择列表中的序号哦~')
        if ClanSecletProcess[qqid].SelectList and str(msg).isdigit():
            if int(msg) <= len( ClanSecletProcess[qqid].SelectList):
                ClanSecletProcess[qqid] = ClanSecletProcess[qqid]._replace(state = True)
                ClanSecletProcess[qqid] = ClanSecletProcess[qqid]._replace(SlectIndex = int(msg))
            else:
                await bot.send(ev,'请选择列表中的序号哦~') 
    except Exception:
        logger.warning(traceback.format_exc())
        return

@bot_checkversion.handle()
async def check_version():
    try:
        bot = get_bot()
        url = 'https://benx1n.oss-cn-beijing.aliyuncs.com/version.json'
        async with httpx.AsyncClient() as client:
            resp = await client.get(url, timeout=10)
            result = json.loads(resp.text)
        superid = get_driver().config.superusers
        match,msg = False,f'发现新版本'
        for each in result['data']:
            if each['version'] > __version__:
                match = True
                msg += f"\n{each['date']} v{each['version']}\n"
                for i in each['description']:
                    msg += f"{i}\n"
        if match:
            for each in superid:
                await bot.send_private_msg(user_id=int(each),message=msg)
            try:
                await bot_checkversion.send(msg)
            except Exception:
                return
        return
    except Exception:
        logger.warning(traceback.format_exc())
        return
        
@driver.on_startup
async def startup():
    try:
        loop = asyncio.get_running_loop()
        url = 'https://benx1n.oss-cn-beijing.aliyuncs.com/template_Hikari/template.json'
        async with httpx.AsyncClient() as client:
            resp = await client.get(url, timeout=20)
            result = resp.json()
            for each in result:
                for name, url in each.items():
                    async with httpx.AsyncClient() as client:
                        resp = resp = await client.get(url, timeout=20)
                        with open(template_path/name , "wb+") as file:
                            file.write(resp.content)
    except Exception:
        logger.error(traceback.format_exc())
        return    
    
scheduler.add_job(
    check_version,
    "cron",
    hour = 12,
)
scheduler.add_job(
    startup,
    "cron",
    hour = 4
)


import httpx
import traceback
import jinja2
import asyncio
from pathlib import Path
from nonebot.adapters.onebot.v11 import MessageSegment
from .data_source import servers,set_shipparams,tiers,number_url_homes,set_ShipRank_Numbers
from .utils import match_keywords
from nonebot_plugin_htmlrender import html_to_pic,text_to_pic
from .wws_ship import ShipSecletProcess,ShipSlectState
from.publicAPI import get_ship_byName
from bs4 import BeautifulSoup
from nonebot import get_driver
from nonebot.log import logger
from httpx import ConnectTimeout
from asyncio.exceptions import TimeoutError

dir_path = Path(__file__).parent
template_path = dir_path / "template"

env = jinja2.Environment(
    loader=jinja2.FileSystemLoader(template_path), enable_async=True
)

headers = {
    'Authorization': get_driver().config.api_token,
    'accept':'application/json',
    'Content-Type':'application/json',
}

async def get_ShipRank(qqid,info,bot):
    try:
        if len(info) == 2:
            param_server,info = await match_keywords(info,servers)
            if param_server and not param_server == 'cn':
                number_url = number_url_homes[param_server] + "/ship/"
            else:
                return '请检查服务器是否正确，暂不支持国服'
        else:
            return '参数似乎出了问题呢'
        shipList = await get_ship_byName(str(info[0]))
        logger.info(f"{shipList}")
        if shipList:
            if len(shipList) < 2:
                select_shipId = shipList[0][0]
                number_url += f"{select_shipId},{shipList[0][2]}"
            else:
                msg = f'存在多条名字相似的船\n请在20秒内选择对应的序号\n================\n'
                flag = 0
                for each in shipList:
                    flag += 1
                    msg += f"{flag}：{tiers[each[3]-1]} {each[1]}\n"
                ShipSecletProcess[qqid] = ShipSlectState(False, None, shipList)
                img = await text_to_pic(text=msg,css_path = str(template_path/"text-ship.css"),width=250) 
                await bot.send(MessageSegment.image(img))
                a = 0
                while a < 40 and not ShipSecletProcess[qqid].state:
                    a += 1
                    await asyncio.sleep(0.5)
                if ShipSecletProcess[qqid].state and ShipSecletProcess[qqid].SlectIndex <= len(shipList):
                    select_shipId = int(shipList[ShipSecletProcess[qqid].SlectIndex-1][0])
                    number_url += f"{select_shipId},{shipList[ShipSecletProcess[qqid].SlectIndex-1][2]}"
                    ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
                else:
                    ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
                    return '已超时退出'
        else:
            return '找不到船'
        content = await search_ShipRank_Yuyuko(select_shipId,param_server)
        if content:                                         #存在缓存，直接出图
            return await html_to_pic(content, wait=0, viewport={"width": 1300, "height": 100})
        else:                                               #无缓存，去Number爬
            content,numbers_data = await search_ShipRank_Numbers(number_url,param_server,select_shipId)
            if content:
                await post_ShipRank(numbers_data)     #上报Yuyuko
                return await html_to_pic(content, wait=0, viewport={"width": 1300, "height": 100})
            else:
                return 'wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~'   
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return '请求超时了，请过会儿再尝试哦~'
    except Exception:
        logger.error(traceback.format_exc())
        return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~' 
   
async def search_ShipRank_Yuyuko(shipId,server):
    try:
        content = None
        async with httpx.AsyncClient(headers=headers) as client:        #查询是否有缓存
            url = 'https://api.wows.shinoaki.com/upload/numbers/data/v2/upload/ship/rank'
            params = {
                "server":server,
                "shipId":int(shipId)
            }
            logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
            resp = await client.get(url, params=params,timeout=None)
            result = resp.json()
            logger.info(f"本次请求返回的状态码:{result['code']}")
            if result['code'] == 200 and result['data']:
                template = env.get_template("ship-rank.html")
                result_data = {"data":result['data']}
                content = await template.render_async(result_data)
                return content
            else:
                return None
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return None 
    except Exception:
        logger.error(traceback.format_exc())
        return None 
        
async def search_ShipRank_Numbers(url,server,shipId):
    try:
        content = None
        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}")
        async with httpx.AsyncClient() as client:
            resp = await client.get(url, timeout=None)
            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
        soup = BeautifulSoup(resp.content, 'html.parser')
        data = soup.select('tr[class="cells-middle"]')
        infoList = await set_ShipRank_Numbers(data,server,shipId)
        if infoList:
            result_data = {"data":infoList}
            template = env.get_template("ship-rank.html")
            content = await template.render_async(result_data)
            return content,infoList
        else:
            return None,None
    except Exception:
        logger.error(traceback.format_exc())
        return None,None
            
async def post_ShipRank(data):
    try:
        async with httpx.AsyncClient(headers=headers) as client:
            url = 'https://api.wows.shinoaki.com/upload/numbers/data/v2/upload/ship/rank'
            resp = await client.post(url, json = data, timeout=None)
            result = resp.json()
            logger.info(result)
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
    except Exception:
        logger.error(traceback.format_exc())


import io
import gzip
import pytz
import time
from collections import defaultdict
from datetime import datetime, timedelta

async def match_keywords(match_list,Lists):
    for List in Lists :                        
        for kw in List.keywords:
            for match_kw in match_list:
                if match_kw == kw or match_kw.upper() == kw.upper() or match_kw.lower() == kw.lower():
                    match_list.remove(match_kw)
                    return List.match_keywords,match_list
    return None,match_list

async def find_and_replace_keywords(match_list,Lists):
    for List in Lists :                        
        for kw in List.keywords:
            for i,match_kw in enumerate(match_list):
                if (match_kw.find(kw)+1):
                    match_list[i] = str(match_kw).replace(kw,"")
                    if match_list[i] == '':
                        match_list.remove('')
                    return List.match_keywords,match_list
    return None,match_list

def encode_gzip(bytes):
    buf = io.BytesIO(bytes)
    gf = gzip.GzipFile(fileobj = buf)
    return gf.read().decode('utf-8')

class FreqLimiter:
    def __init__(self, default_cd_seconds):
        self.next_time = defaultdict(float)
        self.default_cd = default_cd_seconds

    def check(self, key) -> bool:
        return bool(time.time() >= self.next_time[key])

    def start_cd(self, key, cd_time=0):
        self.next_time[key] = time.time() + (cd_time if cd_time > 0 else self.default_cd)

    def left_time(self, key) -> float:
        return self.next_time[key] - time.time()

class DailyNumberLimiter:
    tz = pytz.timezone('Asia/Shanghai')

    def __init__(self, max_num):
        self.today = -1
        self.count = defaultdict(int)
        self.max = max_num

    def check(self, key) -> bool:
        now = datetime.now(self.tz)
        day = (now - timedelta(hours=5)).day
        if day != self.today:
            self.today = day
            self.count.clear()
        return bool(self.count[key] < self.max)

    def get_num(self, key):
        return self.count[key]

    def increase(self, key, num=1):
        self.count[key] += num

    def reset(self, key):
        self.count[key] = 0
        



from typing import List
import httpx
import traceback
import jinja2
import re
import asyncio
from pathlib import Path
from .data_source import servers
from .utils import match_keywords
from nonebot_plugin_htmlrender import html_to_pic,text_to_pic
from nonebot.adapters.onebot.v11 import MessageSegment,ActionFailed
from.publicAPI import get_ClanIdByName
from collections import defaultdict, namedtuple
from nonebot import get_driver
from nonebot.log import logger
from httpx import ConnectTimeout
from asyncio.exceptions import TimeoutError

dir_path = Path(__file__).parent
template_path = dir_path / "template"
env = jinja2.Environment(
    loader=jinja2.FileSystemLoader(template_path), enable_async=True
)

headers = {
    'Authorization': get_driver().config.api_token
}

ClanSlectState = namedtuple("ClanSlectState", ['state','SlectIndex','SelectList'])
ClanSecletProcess = defaultdict(lambda: ClanSlectState(False, None, None))

async def get_ClanInfo(server_type,qqid,info,bot):
    try:
        params = None
        if isinstance(info,List):
            for flag,i in enumerate(info):              #是否包含me或@，包含则调用平台接口
                if i == 'me':
                    url = ''
                    params = {
                    "server": server_type,
                    "clanId": qqid,
                    }
                    info.remove("me")
                match = re.search(r"CQ:at,qq=(\d+)",i)
                if match:
                    url = ''
                    params = {
                    "server": server_type,
                    "clanId": match.group(1),
                    }
                    info[flag] = str(i).replace(f"[{match.group(0)}]",'')
                    if not info[flag]:
                        info.remove('')
                    break
            if not params and len(info) == 2:
                param_server,info = await match_keywords(info,servers)
                if param_server:
                    clanList = await get_ClanIdByName(param_server,str(info[0])) 
                    if clanList:
                        if len(clanList) < 2:
                            selectClanId = clanList[0]['clanId']
                        else:
                            msg = f'存在多个名字相似的军团\n请在20秒内选择对应的序号\n================\n'
                            flag = 0
                            for each in clanList:
                                flag += 1
                                msg += f"{flag}：[{each['tag']}]\n"
                            ClanSecletProcess[qqid] = ClanSlectState(False, None, clanList)
                            img = await text_to_pic(text=msg,css_path = template_path/"text-ship.css",width=250)
                            await bot.send(MessageSegment.image(img))
                            a = 0
                            while a < 40 and not ClanSecletProcess[qqid].state:
                                a += 1
                                await asyncio.sleep(0.5)
                            if ClanSecletProcess[qqid].state and ClanSecletProcess[qqid].SlectIndex <= len(clanList):
                                selectClanId = clanList[ClanSecletProcess[qqid].SlectIndex-1]['clanId']
                                ClanSecletProcess[qqid] = ClanSlectState(False, None, None)
                            else:
                                return '已超时退出'
                    else:
                        return '找不到军团'
                    if selectClanId :
                        url = ''
                        params = {
                        "server": param_server,
                        "clanId": selectClanId,
                        }
                    else:
                        return '发生了错误，有可能是网络波动，请稍后再试'
                else:
                    return '服务器参数似乎输错了呢'
            else:
                return '您似乎准备用军团名查询军团详情，请检查参数中是否包含服务器、军团名，以空格区分'
        else:
            return '参数似乎出了问题呢'
        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{params}")
        async with httpx.AsyncClient(headers=headers) as client:
            resp = await client.get(url, params=params, timeout=20)
            result = resp.json()
        if result['code'] == 200 and result['data']:
            template = env.get_template("wws-clan.html")
            #template_data = await set_clanparams(result['data'])
            #content = await template.render_async(template_data)
            #return await html_to_pic(content, wait=0, viewport={"width": 800, "height": 100})
        elif result['code'] == 403:
            return f"{result['message']}\n请先绑定账号"
        elif result['code'] == 404 or result['code'] == 405:
            return f"{result['message']}"
        elif result['code'] == 500:
            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
        else:
            return 'wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~'
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return '请求超时了，请过会儿再尝试哦~'
    except ActionFailed:
        logger.warning(traceback.format_exc())
        return '由于风控或禁言，无法发送消息'
    except Exception:
        logger.error(traceback.format_exc())
        return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'


from typing import List
import httpx
import traceback
import json
import jinja2
import re
import time
from pathlib import Path
from .data_source import servers,set_clanRecord_params
from .publicAPI import get_AccountIdByName
from .utils import match_keywords
from .wws_clan import ClanSlectState,ClanSecletProcess
from nonebot import get_driver
from nonebot_plugin_htmlrender import html_to_pic
from bs4 import BeautifulSoup

dir_path = Path(__file__).parent
template_path = dir_path / "template"
env = jinja2.Environment(
    loader=jinja2.FileSystemLoader(template_path), enable_async=True
)

headers = {
    'Authorization': get_driver().config.api_token
}

  

async def get_record(server_type,qqid,info,type):
    try:
        params = None
        if isinstance(info,List):
            for i in info:
                if i == 'me':
                    params = {
                    "server": server_type,
                    "accountId": int(qqid)
                    }
                    break
                match = re.search(r"CQ:at,qq=(\d+)",i)
                if match:
                    params = {
                    "server": server_type,
                    "accountId": int(match.group(1))
                    }
                    break
            if not params and len(info) == 2:
                param_server,info = await match_keywords(info,servers)
                if param_server and param_server != 'cn':
                    param_accountid = await get_AccountIdByName(param_server,str(info[0]))
                    if isinstance(param_accountid,int):   
                        params = {
                        "server": param_server,
                        "accountId": param_accountid
                        }
                    else:
                        return f"{param_accountid}"
                elif param_server == 'cn':
                    return '暂不支持国服'
                else:
                    return '服务器参数似乎输错了呢'
            elif params:
                print('下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦')
            else:
                return '您似乎准备用游戏昵称查询公会进出记录，请检查参数中时候包含服务器和游戏昵称，以空格区分，如果您准备查询单船战绩，请带上ship参数'
        else:
            return '参数似乎出了问题呢'
        print(params)
        if type == 'personal':
            url = 'https://api.wows.shinoaki.com/upload/numbers/data/upload/user/clan/record'
            async with httpx.AsyncClient(headers=headers) as client:
                resp = await client.get(url, params=params, timeout=None)
                result = resp.json()
            if result['code'] == 200 and result['data']:
                template = env.get_template("wws-personalRecord.html")
                template_data = {"data":result['data']}
                content = await template.render_async(template_data)
                return await html_to_pic(content, wait=0, viewport={"width": 920, "height": 100})
            elif result['code'] == 403:
                return f"{result['message']}\n请检查昵称或绑定账号"
            elif result['code'] == 404:
                template = env.get_template("wws-personalRecord.html")
                template_data = await get_personalRecord_Numbers(result['data'][0]['httpUrl'],params)
                print(template_data)
                if template_data:
                    template_data = {"data":template_data}
                else:
                    return '查询失败了呢，可能是没有进出记录'
                content = await template.render_async(template_data)
                return await html_to_pic(content, wait=0, viewport={"width": 920, "height": 100})
            elif result['code'] == 500:
                return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
            else:
                return f"{result['message']}"
        else:
            url = ''
            async with httpx.AsyncClient(headers=headers) as client:
                resp = await client.get(url, params=params, timeout=None)
                result = resp.json()
            if result['code'] == 200 and result['data']:
                template = env.get_template("wws-clanRecord.html")
                template_data = {"data":result['data']}
                content = await template.render_async(template_data)
                return await html_to_pic(content, wait=0, viewport={"width": 920, "height": 100})
            elif result['code'] == 403:
                return f"{result['message']}\n请检查昵称或绑定账号"
            elif result['code'] == 404:
                template = env.get_template("wws-clanRecord.html")
                template_data = await get_ClanRecord_Numbers(result['data'][0]['httpUrl'],params['server'],params['accountId'])
                print(template_data)
                if template_data:
                    template_data = {"data":template_data}
                else:
                    return '查询失败了呢，可能是没有进出记录'
                content = await template.render_async(template_data)
                return await html_to_pic(content, wait=0, viewport={"width": 920, "height": 100})
            elif result['code'] == 500:
                return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
            else:
                return f"{result['message']}"
            
    except Exception:
        traceback.print_exc()
        return 'wuwuwu出了点问题，请联系麻麻解决，目前不支持国服哦'
    
    
async def get_personalRecord_Numbers(url,server,accountId):
    try:
        data = None
        async with httpx.AsyncClient() as client:
            resp = await client.get(url, timeout=None)
            soup = BeautifulSoup(resp.content, 'html.parser')
            data = soup.select(f'table[id="moreTransfers"]')
            if data:
                data = data.select(f'tr')
            else:
                data = soup.select(f'table[class="table table-styled table-bordered cells-middle"]')
                data = data[len(data)-1].select(f'tr')
            info,info_list,clan_list = {},[],[]
            for each in data:
                class_list = each.select('td span')[0].attrs['class']
                if class_list[2] == 'transfer-out':
                    status = 1
                else:
                    status = 0
                timeGroup = re.match( r'(.*?)\.(.*?)\.(.*?)$', each.select('td')[1].string)
                dt = f"{timeGroup.group(3)}-{timeGroup.group(2)}-{timeGroup.group(1)} 12:00:00"
                timestamp = int(time.mktime(time.strptime(dt, r"%Y-%m-%d %H:%M:%S")))
                clanId = re.match( r'\/clan\/(.*?),', each.select('td a')[0].attrs['href']).group(1)
                clanName = each.select('td a')[0].string
                info['server'] = server
                info['accountId'] = accountId
                info['clanId'] = int(clanId)
                info['status'] = status
                info['time'] = timestamp
                info['clanName'] = clanName
                if clanId not in clan_list:
                    clan_list.append(clanId)
                info_list.append(info.copy())
            print(clan_list)
            clan_url = re.match( r'(.*?)player', url).group(1)
            for each in clan_list:
                await get_ClanRecord_Numbers(f"{clan_url}clan/transfers/{each},111/",each)
            #result = await post_personalRecord_yuyuko(info_list)
            #if result:
            #    return result
            #else:
            #    return None
    except Exception:
        traceback.print_exc()
        return None
    
    
async def get_ClanRecord_Numbers(url,clanId):
    async with httpx.AsyncClient() as client:
        resp = await client.get(url, timeout=None)
        soup = BeautifulSoup(resp.content, 'html.parser')
        data = soup.select(f'tr')
        info,info_list={},[]
        for each_data in data[2:]:
            class_list = each_data.select('td span')[0].attrs['class']
            if class_list[2] == 'transfer-out':
                status = 1
            else:
                status = 0
            timeGroup = re.match( r'(.*?)\.(.*?)\.(.*?)$', each_data.select('td')[1].string)
            dt = f"{timeGroup.group(3)}-{timeGroup.group(2)}-{timeGroup.group(1)} 12:00:00"
            timestamp = int(time.mktime(time.strptime(dt, r"%Y-%m-%d %H:%M:%S")))
            accountMacthGroup = re.match( r'\/player\/(.*?),(.*?)\/', each_data.select('td a')[0].attrs['href'])
            if accountMacthGroup:
                accountId = accountMacthGroup.group(1)
                accountName = accountMacthGroup.group(2)
            info['clanId'] = clanId
            info['status'] = status
            info['time'] = timestamp
            info['accountId'] = accountId
            info['accountName'] = accountName
            info_list.append(info.copy())
    
        
async def post_personalRecord_yuyuko(post_data):
    try:
        async with httpx.AsyncClient(headers=headers) as client:
            url = 'https://api.wows.shinoaki.com/upload/numbers/data/upload/user/clan/record'
            resp = await client.post(url, json = post_data, timeout=None)
            result = resp.json()
            if result['code'] == 200 and result['data']:
                return result['data']
            else:
                return None
    except Exception:
        traceback.print_exc()
        return None


from dataclasses import dataclass
from typing import Tuple,List
import time
import traceback
from pathlib import Path
import re

dir_path = Path(__file__).parent
template_path = dir_path / "template"

@dataclass
class matching:
    keywords: Tuple[str, ...]
    match_keywords : str
    
command_list = [        #同指令中越长的匹配词越靠前
    matching(("切换绑定","更换绑定","更改绑定"),"changebind"),
    matching(("查询绑定","绑定查询","绑定列表","查绑定"),"bindlist"),
    matching(("删除绑定",),"delete_bind"),
    matching(("特殊绑定",),"special_bind"),
    matching(("ship.rank","SHIP.RANK","rank","RANK"),"ship_rank"),
    matching(("bind","BIND","绑定","set","SET"),"bind"),
    matching(("recent","RECENT","近期",),"recent"),
    matching(("ship","SHIP","单船",),"ship"),
    matching(("record","历史记录"),"record"),
    matching(("搜船名","查船名","船名"),"searchship"),
    matching(("clan","军团","公会","工会"),"clan"),
    matching(("help","HELP","帮助"),"help"),
]

nations = [
    matching(("commonwealth","英联邦",),"commonwealth"),
    matching(("europe","欧洲",),"europe"),
    matching(("france","法国",),"france"),
    matching(("germany","德国",),"germany"),
    matching(("italy","意大利",),"italy"),
    matching(("japan","日本",),"japan"),
    matching(("pan_america","泛美",),"pan_america"),
    matching(("pan_asia","泛亚",),"pan_asia"),
    matching(("uk","英国","United_Kingdom"),"United_Kingdom"),
    matching(("usa","美国",),"usa"),
    matching(("ussr","苏联",),"Russia"),
    matching(("netherlands","荷兰",),"netherlands"),
    matching(("spain","西班牙",),"spain"),
]

shiptypes = [
    matching(("Cruiser","巡洋舰","巡洋","CA"),"Cruiser"),
    matching(("Battleship","战列舰","战列","BB"),"Battleship"),
    matching(("Destroyer","驱逐舰","驱逐","DD"),"Destroyer"),
    matching(("Submarine","潜艇","SS"),"Submarine"),
    matching(("Auxiliary","辅助舰艇","DD"),"Auxiliary"),
    matching(("AirCarrier","航空母舰","航母","CV"),"AirCarrier"),
]

levels = [
    matching(("1","1级","一级","一"),"1"),
    matching(("2","2级","二级","二"),"2"),
    matching(("3","3级","三级","三"),"3"),
    matching(("4","4级","四级","四"),"4"),
    matching(("4","4级","四级","四"),"4"),
    matching(("5","5级","五级","五"),"5"),
    matching(("6","6级","六级","六"),"6"),
    matching(("7","7级","七级","七"),"7"),
    matching(("8","8级","八级","八"),"8"),
    matching(("9","9级","九级","九"),"9"),
    matching(("10","10级","十级","十"),"10"),
    matching(("11","11级","十一级","十一"),"11"),
]

servers = [
    matching(("asia","亚服","asian"),"asia"),
    matching(("eu","欧服","europe"),"eu"),
    matching(("na","美服","NorthAmerican"),"na"),
    matching(("ru","俄服","Russia"),"ru"),
    matching(("cn","国服","china"),"cn"),
]

tiers = ["Ⅰ", "Ⅱ", "Ⅲ", "Ⅳ", "Ⅴ", "Ⅵ", "Ⅶ", "Ⅷ", "Ⅸ", "Ⅹ", "Ⅺ"]

number_url_homes={
    "asia":"https://asia.wows-numbers.com",
    "eu":"https://wows-numbers.com",
    "na":"https://na.wows-numbers.com",
    "ru":"https://ru.wows-numbers.com",
    "cn": None
}

pr_select = [
    {
        "value": 0,
        "name": "还需努力",
        "englishName": "Bad",
        "color": "#FE0E00"
    },
    {
        "value": 750,
        "name": "低于平均",
        "englishName": "Below Average",
        "color": "#FE7903"
    },
    {
        "value": 1100,
        "name": "平均水平",
        "englishName": "Average",
        "color": "#FFC71F"
    },
    {
        "value": 1350,
        "name": "好",
        "englishName": "Good",
        "color": "#44B300"
    },
    {
        "value": 1550,
        "name": "很好",
        "englishName": "Very Good",
        "color": "#318000"
    },
    {
        "value": 1750,
        "name": "非常好",
        "englishName": "Great",
        "color": "#02C9B3"
    },
    {
        "value": 2100,
        "name": "大佬水平",
        "englishName": "Unicum",
        "color": "#D042F3"
    },
    {
        "value": 2450,
        "name": "神佬水平",
        "englishName": "Super Unicum",
        "color": "#A00DC5"
    }
]

color_data = {
    "Bad": "#FE0E00",
    "Below Average": "#FE7903",
    "Average": "#FFC71F",
    "Good": "#44B300",
    "Very Good": "#318000",
    "Great": "#02C9B3",
    "Unicum": "#D042F3",
    "Super Unicum": "#A00DC5"
}

async def set_infoparams(List):
    try:
        winsColor = await set_winColor(List['pvp']['wins'])
        damageColor = await set_damageColor(None,List['pvp']['damage'])
        bb_winsColor = await set_winColor(List['type']['Battleship']['wins'])
        ca_winsColor = await set_winColor(List['type']['Cruiser']['wins'])
        dd_winsColor = await set_winColor(List['type']['Destroyer']['wins'])
        cv_winsColor = await set_winColor(List['type']['AirCarrier']['wins'])
        bb_damageColor = await set_damageColor(None,List['type']['Battleship']['damage'])
        ca_damageColor = await set_damageColor('Cruiser',List['type']['Cruiser']['damage'])
        dd_damageColor = await set_damageColor('Destroyer',List['type']['Destroyer']['damage'])
        cv_damageColor = await set_damageColor('AirCarrier',List['type']['AirCarrier']['damage'])
        solo_winsColor = await set_winColor(List['pvpSolo']['wins'])
        solo_damageColor = await set_damageColor(None,List['pvpSolo']['damage'])
        div2_winsColor = await set_winColor(List['pvpTwo']['wins'])
        div2_damageColor = await set_damageColor(None,List['pvpTwo']['damage'])
        div3_winsColor = await set_winColor(List['pvpThree']['wins'])
        div3_damageColor = await set_damageColor(None,List['pvpThree']['damage'])
        rank_winsColor = await set_winColor(List['rankSolo']['wins'])
        rank_damageColor = await set_damageColor(None,List['rankSolo']['damage'])
        newDamageColor = await set_upinfo_color(List['dwpDataVO']['damage'])
        newWinsColor = await set_upinfo_color(List['dwpDataVO']['wins'])
        newPrColor = await set_upinfo_color(List['dwpDataVO']['pr'])
        result = {
            "template_path":template_path,
            "guild":List['clanInfo']['tag'],
            "userName":List['userName'],
            "karma":List['karma'],
            "serverName":List['serverName'],
            "newDamage":f"{List['dwpDataVO']['damage']:+} ",
            "newWins":f"{List['dwpDataVO']['wins']:+.2f}",
            "newPr":f"{List['dwpDataVO']['pr']:+}",
            "prValue":f"{List['pr']['value']} {List['pr']['name']}",
            "time":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(abs(List['lastDateTime']))),
            "battles":List['pvp']['battles'],
            "wins":List['pvp']['wins'],
            "damage":List['pvp']['damage'],
            "xp":List['pvp']['xp'],
            "kd":List['pvp']['kd'],
            "frags":f"{List['pvp']['frags']:.2f}",
            "hit":List['pvp']['hit'],
            "bb_battles":List['type']['Battleship']['battles'],
            "bb_pr":List['type']['Battleship']['pr']['value'],
            "bb_wins":List['type']['Battleship']['wins'],
            "bb_damage":List['type']['Battleship']['damage'],
            "bb_hit":List['type']['Battleship']['hit'],
            "ca_battles":List['type']['Cruiser']['battles'],
            "ca_pr":List['type']['Cruiser']['pr']['value'],
            "ca_wins":List['type']['Cruiser']['wins'],
            "ca_damage":List['type']['Cruiser']['damage'],
            "ca_hit":List['type']['Cruiser']['hit'],
            "dd_battles":List['type']['Destroyer']['battles'],
            "dd_pr":List['type']['Destroyer']['pr']['value'],
            "dd_wins":List['type']['Destroyer']['wins'],
            "dd_damage":List['type']['Destroyer']['damage'],
            "dd_hit":List['type']['Destroyer']['hit'], 
            "cv_battles":List['type']['AirCarrier']['battles'],
            "cv_pr":List['type']['AirCarrier']['pr']['value'],
            "cv_wins":List['type']['AirCarrier']['wins'],
            "cv_damage":List['type']['AirCarrier']['damage'],
            "cv_hit":List['type']['AirCarrier']['hit'],      
            "solo_battles":List['pvpSolo']['battles'],
            "solo_wins":List['pvpSolo']['wins'],
            "solo_pr":List['pvpSolo']['pr']['value'],
            "solo_xp":List['pvpSolo']['xp'],
            "solo_damage":List['pvpSolo']['damage'],
            "solo_kd":List['pvpSolo']['kd'],
            "solo_hit":List['pvpSolo']['hit'],
            "solo_frags":f"{List['pvpSolo']['frags']:.2f}",
            "div2_battles":List['pvpTwo']['battles'],
            "div2_wins":List['pvpTwo']['wins'],
            "div2_pr":List['pvpTwo']['pr']['value'],
            "div2_xp":List['pvpTwo']['xp'],
            "div2_damage":List['pvpTwo']['damage'],
            "div2_kd":List['pvpTwo']['kd'],
            "div2_hit":List['pvpTwo']['hit'],
            "div2_frags":f"{List['pvpTwo']['frags']:.2f}",
            "div3_battles":List['pvpThree']['battles'],
            "div3_wins":List['pvpThree']['wins'],
            "div3_pr":List['pvpThree']['pr']['value'],
            "div3_xp":List['pvpThree']['xp'],
            "div3_damage":List['pvpThree']['damage'],
            "div3_kd":List['pvpThree']['kd'],
            "div3_hit":List['pvpThree']['hit'],
            "div3_frags":f"{List['pvpThree']['frags']:.2f}",
            "rank_battles":List['rankSolo']['battles'],
            "rank_wins":List['rankSolo']['wins'],
            "rank_pr":List['rankSolo']['pr']['value'],
            "rank_xp":List['rankSolo']['xp'],
            "rank_damage":List['rankSolo']['damage'],
            "rank_kd":List['rankSolo']['kd'],
            "rank_hit":List['rankSolo']['hit'],
            "rank_frags":f"{List['rankSolo']['frags']:.2f}",
            "lv1":List['battleCountAll']['1'],
            "lv2":List['battleCountAll']['2'],
            "lv3":List['battleCountAll']['3'],
            "lv4":List['battleCountAll']['4'],
            "lv5":List['battleCountAll']['5'],
            "lv6":List['battleCountAll']['6'],
            "lv7":List['battleCountAll']['7'],
            "lv8":List['battleCountAll']['8'],
            "lv9":List['battleCountAll']['9'],
            "lv10":List['battleCountAll']['10'],
            "lv11":List['battleCountAll']['11'],
            "newDamageColor":newDamageColor,
            "newWinsColor":newWinsColor,
            "newPrColor":newPrColor,
            "prValueColor":List['pr']['color'],
            "winsColor":winsColor,
            "damageColor":damageColor,
            "bb_prColor":List['type']['Battleship']['pr']['color'],
            "ca_prColor":List['type']['Cruiser']['pr']['color'],
            "dd_prColor":List['type']['Destroyer']['pr']['color'],
            "cv_prColor":List['type']['AirCarrier']['pr']['color'],
            "solo_prColor":List['pvpSolo']['pr']['color'],
            "div2_prColor":List['pvpTwo']['pr']['color'],
            "div3_prColor":List['pvpThree']['pr']['color'],
            "rank_prColor":List['rankSolo']['pr']['color'],
            "clanColor":List['clanInfo']['colorRgb'],
            "bb_winsColor":bb_winsColor,
            "ca_winsColor":ca_winsColor,
            "dd_winsColor":dd_winsColor,
            "cv_winsColor":cv_winsColor,
            "bb_damageColor":bb_damageColor,
            "ca_damageColor":ca_damageColor,
            "dd_damageColor":dd_damageColor,
            "cv_damageColor":cv_damageColor,
            "solo_winsColor":solo_winsColor,
            "solo_damageColor":solo_damageColor,
            "div2_winsColor":div2_winsColor,
            "div2_damageColor":div2_damageColor,
            "div3_winsColor":div3_winsColor,
            "div3_damageColor":div3_damageColor,
            "rank_winsColor":rank_winsColor,
            "rank_damageColor":rank_damageColor
        }
        return result
    except Exception:
        traceback.print_exc()

async def set_recentparams(List):
    try:   
        InfoRecent_RandomData = await set_InfoRecent_RandomData(List['shipData'][0])
        InfoRecent_RankData = await set_InfoRecent_RankData(List['shipData'][0])
        winsColor = await set_winColor(List['shipData'][0]['pvpInfo']['wins'])
        damageColor = await set_damageColor(None,List['shipData'][0]['pvpInfo']['damage'])
        solo_winsColor = await set_winColor(List['shipData'][0]['pvpSoloInfo']['wins'])
        solo_damageColor = await set_damageColor(None,List['shipData'][0]['pvpSoloInfo']['damage'])
        div2_winsColor = await set_winColor(List['shipData'][0]['pvpTwoInfo']['wins'])
        div2_damageColor = await set_damageColor(None,List['shipData'][0]['pvpTwoInfo']['damage'])
        div3_winsColor = await set_winColor(List['shipData'][0]['pvpThreeInfo']['wins'])
        div3_damageColor = await set_damageColor(None,List['shipData'][0]['pvpThreeInfo']['damage'])
        rank_winsColor = await set_winColor(List['shipData'][0]['rankInfo']['wins'])
        rank_damageColor = await set_damageColor(None,List['shipData'][0]['rankInfo']['damage'])
        result = {
            "guild":List['clanInfo']['tag'],
            "userName":List['userName'],
            "serverName":List['serverName'],
            "prValue":f"{List['shipData'][0]['pvpInfo']['pr']['value']} {List['shipData'][0]['pvpInfo']['pr']['name']}",
            "reTime":time.strftime('%Y-%m-%d %H:%M',time.localtime(int(abs(List['shipData'][0]['recordDateTime']/1000)))),
            "nowTime":time.strftime('%Y-%m-%d %H:%M',time.localtime(time.time())),
            "battles":List['shipData'][0]['pvpInfo']['battles'],
            "wins":List['shipData'][0]['pvpInfo']['wins'],
            "damage":List['shipData'][0]['pvpInfo']['damage'],
            "xp":List['shipData'][0]['pvpInfo']['xp'],
            "kd":List['shipData'][0]['pvpInfo']['kd'],
            "hit":f"{List['shipData'][0]['pvpInfo']['hit']:.2f}",
            "frags":f"{List['shipData'][0]['pvpInfo']['frags']:.2f}",
            "solo_battles":List['shipData'][0]['pvpSoloInfo']['battles'],
            "solo_wins":List['shipData'][0]['pvpSoloInfo']['wins'],
            "solo_pr":f"{List['shipData'][0]['pvpSoloInfo']['pr']['value']} {List['shipData'][0]['pvpSoloInfo']['pr']['name']}",
            "solo_xp":List['shipData'][0]['pvpSoloInfo']['xp'],
            "solo_damage":List['shipData'][0]['pvpSoloInfo']['damage'],
            "solo_kd":List['shipData'][0]['pvpSoloInfo']['kd'],
            "solo_hit":f"{List['shipData'][0]['pvpSoloInfo']['hit']:.2f}",
            "solo_frags":f"{List['shipData'][0]['pvpSoloInfo']['frags']:.2f}",
            "div2_battles":List['shipData'][0]['pvpTwoInfo']['battles'],
            "div2_wins":List['shipData'][0]['pvpTwoInfo']['wins'],
            "div2_pr":f"{List['shipData'][0]['pvpTwoInfo']['pr']['value']} {List['shipData'][0]['pvpTwoInfo']['pr']['name']}",
            "div2_xp":List['shipData'][0]['pvpTwoInfo']['xp'],
            "div2_damage":List['shipData'][0]['pvpTwoInfo']['damage'],
            "div2_kd":List['shipData'][0]['pvpTwoInfo']['kd'],
            "div2_hit":f"{List['shipData'][0]['pvpTwoInfo']['hit']:.2f}",
            "div2_frags":f"{List['shipData'][0]['pvpTwoInfo']['frags']:.2f}",
            "div3_battles":List['shipData'][0]['pvpThreeInfo']['battles'],
            "div3_wins":List['shipData'][0]['pvpThreeInfo']['wins'],
            "div3_pr":f"{List['shipData'][0]['pvpThreeInfo']['pr']['value']} {List['shipData'][0]['pvpThreeInfo']['pr']['name']}",
            "div3_xp":List['shipData'][0]['pvpThreeInfo']['xp'],
            "div3_damage":List['shipData'][0]['pvpThreeInfo']['damage'],
            "div3_kd":List['shipData'][0]['pvpThreeInfo']['kd'],
            "div3_hit":f"{List['shipData'][0]['pvpThreeInfo']['hit']:.2f}",
            "div3_frags":f"{List['shipData'][0]['pvpThreeInfo']['frags']:.2f}",
            "rank_battles":List['shipData'][0]['rankInfo']['battles'],
            "rank_wins":List['shipData'][0]['rankInfo']['wins'],
            "rank_pr":f"{List['shipData'][0]['rankInfo']['pr']['value']} {List['shipData'][0]['rankInfo']['pr']['name']}",
            "rank_xp":List['shipData'][0]['rankInfo']['xp'],
            "rank_damage":List['shipData'][0]['rankInfo']['damage'],
            "rank_kd":List['shipData'][0]['rankInfo']['kd'],
            "rank_hit":f"{List['shipData'][0]['rankInfo']['hit']:.2f}",
            "rank_frags":f"{List['shipData'][0]['rankInfo']['frags']:.2f}",
            "InfoRecent_RandomData":InfoRecent_RandomData,
            "InfoRecent_RankData":InfoRecent_RankData,
            "prValueColor":List['shipData'][0]['pvpInfo']['pr']['color'],
            "solo_prColor":List['shipData'][0]['pvpSoloInfo']['pr']['color'],
            "div2_prColor":List['shipData'][0]['pvpTwoInfo']['pr']['color'],
            "div3_prColor":List['shipData'][0]['pvpThreeInfo']['pr']['color'],
            "rank_prColor":List['shipData'][0]['rankInfo']['pr']['color'],
            "clanColor":List['clanInfo']['colorRgb'],
            "winsColor":winsColor,
            "damageColor":damageColor,
            "solo_winsColor":solo_winsColor,
            "solo_damageColor":solo_damageColor,
            "div2_winsColor":div2_winsColor,
            "div2_damageColor":div2_damageColor,
            "div3_winsColor":div3_winsColor,
            "div3_damageColor":div3_damageColor,
            "rank_winsColor":rank_winsColor,
            "rank_damageColor":rank_damageColor
        }
        return result
    except Exception:
        traceback.print_exc()
        
async def set_shipparams(List):
    try:   
        damageTopColor = await set_upinfo_color(List['dwpDataVO']['damage'])
        winsTopColor = await set_upinfo_color(List['dwpDataVO']['wins'])
        prTopColor = await set_upinfo_color(List['dwpDataVO']['pr'])
        winsColor = await set_winColor(List['shipInfo']['wins'])
        damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipInfo']['damage'])
        solo_winsColor = await set_winColor(List['shipSolo']['wins'])
        solo_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipSolo']['damage'])
        div2_winsColor = await set_winColor(List['shipTwo']['wins'])
        div2_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipTwo']['damage'])
        div3_winsColor = await set_winColor(List['shipThree']['wins'])
        div3_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['shipThree']['damage'])
        rank_winsColor = await set_winColor(List['rankSolo']['wins'])
        rank_damageColor = await set_damageColor(List['shipInfo']['shipInfo']['shipType'],List['rankSolo']['damage'])
        if List['shipInfo']['shipInfo']['nameEnglish']:
            shipNameEn = List['shipInfo']['shipInfo']['nameEnglish']
            shipNameCn = List['shipInfo']['shipInfo']['nameCn']
        else:
            shipNameEn = List['rankSolo']['shipInfo']['nameEnglish']
            shipNameCn = List['rankSolo']['shipInfo']['nameEnglish']
        result = {
            "guild":List['clanInfo']['tag'],
            "userName":List['userName'],
            "serverName":List['serverName'],
            "shipNameEn":shipNameEn,
            "shipNameCn":shipNameCn,
            "damageTop":f"{List['dwpDataVO']['damage']:+}",
            "winsTop":f"{List['dwpDataVO']['wins']:+.2f}",
            "prTop":f"{List['dwpDataVO']['pr']:+}",
            "prValue":f"{List['shipInfo']['pr']['value']} {List['shipInfo']['pr']['name']}",
            "lastTime":time.strftime('%Y-%m-%d %H:%M:%S',time.localtime(abs(List['shipInfo']['lastBattlesTime']))),
            "battles":List['shipInfo']['battles'],
            "wins":List['shipInfo']['wins'],
            "damage":List['shipInfo']['damage'],
            "xp":List['shipInfo']['xp'],
            "kda":List['shipInfo']['kd'],
            "hit":List['shipInfo']['hit'],
            "frags":f"{List['shipInfo']['frags']:.2f}",
            "solo_battles":List['shipSolo']['battles'],
            "solo_wins":List['shipSolo']['wins'],
            "solo_pr":List['shipSolo']['pr']['value'],
            "solo_xp":List['shipSolo']['xp'],
            "solo_damage":List['shipSolo']['damage'],
            "solo_kd":List['shipSolo']['kd'],
            "solo_hit":List['shipSolo']['hit'],
            "solo_frags":f"{List['shipSolo']['frags']:.2f}",
            "div2_battles":List['shipTwo']['battles'],
            "div2_wins":List['shipTwo']['wins'],
            "div2_pr":List['shipTwo']['pr']['value'],
            "div2_xp":List['shipTwo']['xp'],
            "div2_damage":List['shipTwo']['damage'],
            "div2_kd":List['shipTwo']['kd'],
            "div2_hit":List['shipTwo']['hit'],
            "div2_frags":f"{List['shipTwo']['frags']:.2f}",
            "div3_battles":List['shipThree']['battles'],
            "div3_wins":List['shipThree']['wins'],
            "div3_pr":List['shipThree']['pr']['value'],
            "div3_xp":List['shipThree']['xp'],
            "div3_damage":List['shipThree']['damage'],
            "div3_kd":List['shipThree']['kd'],
            "div3_hit":List['shipThree']['hit'],
            "div3_frags":f"{List['shipThree']['frags']:.2f}",
            "rank_battles":List['rankSolo']['battles'],
            "rank_wins":List['rankSolo']['wins'],
            "rank_pr":List['rankSolo']['pr']['value'],
            "rank_xp":List['rankSolo']['xp'],
            "rank_damage":List['rankSolo']['damage'],
            "rank_kd":List['rankSolo']['kd'],
            "rank_hit":List['rankSolo']['hit'],
            "rank_frags":f"{List['rankSolo']['frags']:.2f}",
            "maxDamage":List['shipInfo']['extensionDataInfo']['maxDamage'],
            "maxDamageScouting":List['shipInfo']['extensionDataInfo']['maxDamageScouting'],
            "maxTotalAgro":List['shipInfo']['extensionDataInfo']['maxTotalAgro'],
            "maxXp":List['shipInfo']['extensionDataInfo']['maxXp'],
            "maxFragsBattle":List['shipInfo']['extensionDataInfo']['maxFrags'],
            "maxPlanesKilled":List['shipInfo']['extensionDataInfo']['maxPlanesKilled'],
            "prColor":List['shipInfo']['pr']['color'],
            "solo_prColor":List['shipSolo']['pr']['color'],
            "div2_prColor":List['shipTwo']['pr']['color'],
            "div3_prColor":List['shipThree']['pr']['color'],
            "rank_prColor":List['rankSolo']['pr']['color'],
            "clanColor":List['clanInfo']['colorRgb'],
            "damageTopColor":damageTopColor,
            "winsTopColor":winsTopColor,
            "prTopColor":prTopColor,
            "winsColor":winsColor,
            "damageColor":damageColor,
            "solo_winsColor":solo_winsColor,
            "solo_damageColor":solo_damageColor,
            "div2_winsColor":div2_winsColor,
            "div2_damageColor":div2_damageColor,
            "div3_winsColor":div3_winsColor,
            "div3_damageColor":div3_damageColor,
            "rank_winsColor":rank_winsColor,
            "rank_damageColor":rank_damageColor
        }
        return result
    except Exception:
        traceback.print_exc()

async def set_shipRecentparams(List):
    try:   
        damageColor = await set_damageColor(List['shipData'][0]['shipInfo']['shipInfo']['shipType'],List['pvpInfo']['damage'])
        winsColor = await set_winColor(List['pvpInfo']['wins'])
        solo_winsColor = await set_winColor(List['pvpSoloInfo']['wins'])
        solo_damageColor = await set_damageColor(List['shipData'][0]['shipInfo']['shipInfo']['shipType'],List['pvpSoloInfo']['damage'])
        div2_winsColor = await set_winColor(List['pvpTwoInfo']['wins'])
        div2_damageColor = await set_damageColor(List['shipData'][0]['shipInfo']['shipInfo']['shipType'],List['pvpTwoInfo']['damage'])
        div3_winsColor = await set_winColor(List['pvpThreeInfo']['wins'])
        div3_damageColor = await set_damageColor(List['shipData'][0]['shipInfo']['shipInfo']['shipType'],List['pvpThreeInfo']['damage'])
        rank_winsColor = await set_winColor(List['rankInfo']['wins'])
        rank_damageColor = await set_damageColor(List['shipData'][0]['shipInfo']['shipInfo']['shipType'],List['rankInfo']['damage'])
        detail_data = await set_ShipRecent_Data(List['shipData'])
        if List['shipData'][0]['shipInfo']['shipInfo']['nameEnglish']:
            shipNameEn = List['shipData'][0]['shipInfo']['shipInfo']['nameEnglish']
            shipNameCn = List['shipData'][0]['shipInfo']['shipInfo']['nameCn']
        else:
            shipNameEn = List['shipData'][0]['rankSolo']['shipInfo']['nameEnglish']
            shipNameCn = List['shipData'][0]['rankSolo']['shipInfo']['nameCn']
        result = {
            "guild":List['clanInfo']['tag'],
            "userName":List['userName'],
            "serverName":List['serverName'],
            "shipNameEn":shipNameEn,
            "shipNameCn":shipNameCn,
            "prValue":f"{List['pvpInfo']['pr']['value']} {List['pvpInfo']['pr']['name']}",
            "recordTime":time.strftime('%Y-%m-%d %H:%M',time.localtime(int(abs(List['shipData'][0]['recordDateTime']/1000)))),
            "nowTime":time.strftime('%Y-%m-%d %H:%M',time.localtime(time.time())),
            "battles":List['pvpInfo']['battles'],
            "wins":List['pvpInfo']['wins'],
            "damage":List['pvpInfo']['damage'],
            "xp":List['pvpInfo']['xp'],
            "kda":List['pvpInfo']['kd'],
            "hit":List['pvpInfo']['hit'],
            "frags":f"{List['pvpInfo']['frags']:.2f}",
            "solo_battles":List['pvpSoloInfo']['battles'],
            "solo_wins":List['pvpSoloInfo']['wins'],
            "solo_pr":List['pvpSoloInfo']['pr']['value'],
            "solo_xp":List['pvpSoloInfo']['xp'],
            "solo_damage":List['pvpSoloInfo']['damage'],
            "solo_kd":List['pvpSoloInfo']['kd'],
            "solo_hit":List['pvpSoloInfo']['hit'],
            "solo_frags":f"{List['pvpSoloInfo']['frags']:.2f}",
            "div2_battles":List['pvpTwoInfo']['battles'],
            "div2_wins":List['pvpTwoInfo']['wins'],
            "div2_pr":List['pvpTwoInfo']['pr']['value'],
            "div2_xp":List['pvpTwoInfo']['xp'],
            "div2_damage":List['pvpTwoInfo']['damage'],
            "div2_kd":List['pvpTwoInfo']['kd'],
            "div2_hit":List['pvpTwoInfo']['hit'],
            "div2_frags":f"{List['pvpTwoInfo']['frags']:.2f}",
            "div3_battles":List['pvpThreeInfo']['battles'],
            "div3_wins":List['pvpThreeInfo']['wins'],
            "div3_pr":List['pvpThreeInfo']['pr']['value'],
            "div3_xp":List['pvpThreeInfo']['xp'],
            "div3_damage":List['pvpThreeInfo']['damage'],
            "div3_kd":List['pvpThreeInfo']['kd'],
            "div3_hit":List['pvpThreeInfo']['hit'],
            "div3_frags":f"{List['pvpThreeInfo']['frags']:.2f}",
            "rank_battles":List['rankInfo']['battles'],
            "rank_wins":List['rankInfo']['wins'],
            "rank_pr":List['rankInfo']['pr']['value'],
            "rank_xp":List['rankInfo']['xp'],
            "rank_damage":List['rankInfo']['damage'],
            "rank_kd":List['rankInfo']['kd'],
            "rank_hit":List['rankInfo']['hit'],
            "rank_frags":f"{List['rankInfo']['frags']:.2f}",
            "detail_data":detail_data,
            "prColor":List['pvpInfo']['pr']['color'],
            "solo_prColor":List['pvpSoloInfo']['pr']['color'],
            "div2_prColor":List['pvpTwoInfo']['pr']['color'],
            "div3_prColor":List['pvpThreeInfo']['pr']['color'],
            "rank_prColor":List['rankInfo']['pr']['color'],
            "clanColor":List['clanInfo']['colorRgb'],
            "damageColor":damageColor,
            "winsColor":winsColor,
            "solo_winsColor":solo_winsColor,
            "solo_damageColor":solo_damageColor,
            "div2_winsColor":div2_winsColor,
            "div2_damageColor":div2_damageColor,
            "div3_winsColor":div3_winsColor,
            "div3_damageColor":div3_damageColor,
            "rank_winsColor":rank_winsColor,
            "rank_damageColor":rank_damageColor
        }
        return result
    except Exception:
        traceback.print_exc()
        
async def set_ShipRecent_Data(List):
   Recent_Data = ''
   typeList = ['单野','自行车','三轮车','排位']
   for eachShipData in List:
       data = time.strftime('%Y-%m-%d',time.localtime(int(abs(eachShipData['recordDateTime']/1000))))
       if eachShipData['shipInfo']['battles'] or eachShipData['rankSolo']['battles']:
           Recent_Data += f'''<tr><td colspan="6" class="bold-data greyColor" style="text-align: center;">{data}</td></tr>'''
           for each in eachShipData:
               for index,value in enumerate(['shipSolo','shipTwo','shipThree','rankSolo']):
                   if str(each) == value and eachShipData[each]['battles']:
                       type = typeList[index]
                       Recent_Data += f'''
                       <tr>
                           <td class="bold-data greyColor">{type}</td>
                           <td class="blueColor">{eachShipData[each]['battles']}</td>
                           <td class="blueColor" style="color: {await set_winColor(eachShipData[each]['wins'])}">{eachShipData[each]['wins']}%</td>
                           <td class="blueColor" style="color: {eachShipData[each]['pr']['color']}">{eachShipData[each]['pr']['value']}</td>
                           <td class="blueColor" style="color: {await set_damageColor(eachShipData['shipInfo']['shipInfo']['shipType'],eachShipData[each]['damage'])}">{eachShipData[each]['damage']}</td>
                           <td class="blueColor">{eachShipData[each]['frags']:.2f}</td>
                       </tr>'''
                   else:
                       continue
   return Recent_Data


                 
async def select_prvalue_and_color(pr:int):
    for select in pr_select :
        if pr > select['value']:
            describe = select['name']
            color = select['color']
    return describe,color

async def set_InfoRecent_RandomData(List):
    Recent_RandomData = ''
    for ship in List['shipData']:
        if ship['shipInfo']['battles']:
            Recent_RandomData += r'<tr>'
            Recent_RandomData += r'<td colspan="8" class="blueColor">'+f"{ship['shipInfo']['shipInfo']['nameCn']}"+r'</td>'
            Recent_RandomData += r'<td colspan="3" class="blueColor">'+f"{ship['shipInfo']['shipInfo']['level']}"+r'</td>'
            Recent_RandomData += r'<td colspan="3" class="blueColor">'+f"{ship['shipInfo']['battles']}"+r'</td>'
            #Recent_RandomData += f'''<td colspan="7" class="blueColor" style="color: {ship['shipInfo']['pr']['color']}">{ship['shipInfo']['pr']['value']} {ship['shipInfo']['pr']['name']}</td>'''
            Recent_RandomData += f'''<td colspan="4" class="blueColor" style="color: {ship['shipInfo']['pr']['color']}">{ship['shipInfo']['pr']['value']}</td>'''
            Recent_RandomData += r'<td colspan="4" class="blueColor">'+f"{ship['shipInfo']['xp']}"+r'</td>'
            Recent_RandomData += f'''<td class="blueColor" colspan="5" style="color: {await set_winColor(ship['shipInfo']['wins'])}">{ship['shipInfo']['wins']}%</td>'''
            Recent_RandomData += f'''<td colspan="4" class="blueColor" style="color: {await set_damageColor(ship['shipInfo']['shipInfo']['shipType'],ship['shipInfo']['damage'])}">{ship['shipInfo']['damage']}</td>'''
            Recent_RandomData += r'<td colspan="4" class="blueColor">'+f"{ship['shipInfo']['frags']:.2f}"+r'</td>'
            Recent_RandomData += r'<td colspan="4" class="blueColor">'+f"{ship['shipInfo']['hit']:.2f}%"+r'</td>'
            Recent_RandomData += r'</tr>'
    return Recent_RandomData

async def set_InfoRecent_RankData(List):
    Recent_RankData = ''
    for ship in List['shipData']:
        if ship['rankSolo']['battles']:
            Recent_RankData += r'<tr>'
            Recent_RankData += r'<td colspan="8" class="blueColor">'+f"{ship['rankSolo']['shipInfo']['nameCn']}"+r'</td>'
            Recent_RankData += r'<td colspan="3" class="blueColor">'+f"{ship['rankSolo']['shipInfo']['level']}"+r'</td>'
            Recent_RankData += r'<td colspan="3" class="blueColor">'+f"{ship['rankSolo']['battles']}"+r'</td>'
            #Recent_RankData += f'''<td colspan="7" class="blueColor" style="color: {ship['rankSolo']['pr']['color']}">{ship['rankSolo']['pr']['value']} {ship['rankSolo']['pr']['name']}</td>'''
            Recent_RankData += f'''<td colspan="4" class="blueColor" style="color: {ship['rankSolo']['pr']['color']}">{ship['rankSolo']['pr']['value']}</td>'''
            Recent_RankData += r'<td colspan="4" class="blueColor">'+f"{ship['rankSolo']['xp']}"+r'</td>'
            Recent_RankData += f'''<td class="blueColor" colspan="5" style="color: {await set_winColor(ship['rankSolo']['wins'])}">{ship['rankSolo']['wins']}%</td>'''
            Recent_RankData += f'''<td colspan="4" class="blueColor" style="color: {await set_damageColor(ship['rankSolo']['shipInfo']['shipType'],ship['rankSolo']['damage'])}">{ship['rankSolo']['damage']}</td>'''
            Recent_RankData += r'<td colspan="4" class="blueColor">'+f"{ship['rankSolo']['frags']:.2f}"+r'</td>'
            Recent_RankData += r'<td colspan="4" class="blueColor">'+f"{ship['rankSolo']['hit']:.2f}%"+r'</td>'
            Recent_RankData += r'</tr>'
    return Recent_RankData

async def set_ShipRank_Numbers(data,server,shipId):
    try:
        info_list = list()
        for each in data[0:10]:
            index = int(each.select('td')[0].string)
            clan_name = each.select('td[style="text-align: left;  "] a')
            if len(clan_name) > 1:
                tag = clan_name[0].string.replace("[",'').replace("]",'')
                userName = clan_name[1].string
                url = clan_name[1].attrs['href']
            else:
                tag = None
                userName = clan_name[0].string
                url = clan_name[0].attrs['href']
            accountId = await search_accountId(url)
            battles = int(each.select('td span')[0].string.replace(' ',''))
            pr = int(each.select('td span')[1].string.replace(' ',''))
            prColor = await search_color(each.select('td span')[1].attrs['style'])
            wins = float(each.select('td span')[2].string.replace('%',''))
            winsColor = await search_color(each.select('td span')[2].attrs['style'])
            frags = float(each.select('td span')[3].string)
            fragsColor = await search_color(each.select('td span')[3].attrs['style'])
            maxFrags = int(each.select('td span')[4].string)
            damage = int(each.select('td span')[5].string.replace(' ',''))
            damageColor = await search_color(each.select('td span')[5].attrs['style'])
            maxDamage = int(each.select('td span')[6].string.replace(' ',''))
            xp = int(each.select('td span')[7].string.replace(' ',''))
            maxXp = int(each.select('td span')[8].string.replace(' ',''))
            planesDestroyed = float(each.select('td span')[9].string)
            planesDestroyedColor = await search_color(each.select('td span')[9].attrs['style'])
            maxPlanesDestroyed = int(each.select('td span')[10].string)
            info ={
                "accountId":accountId,
                "battles":battles,
                "damage":damage,
                "damageColor":damageColor,
                "frags":frags,
                "fragsColor":fragsColor,
                "index":index,
                "maxDamage":maxDamage,
                "maxFrags":maxFrags,
                "maxPlanesDestroyed":maxPlanesDestroyed,
                "maxXp":maxXp,
                "planesDestroyed":planesDestroyed,
                "planesDestroyedColor":planesDestroyedColor,
                "pr":pr,
                "prColor":prColor,
                "server":server,
                "shipId":shipId,
                "wins":wins,
                "winsColor":winsColor,
                "xp":xp,
                "tag":tag,
                "userName":userName
            }
            info_list.append(info)
        return info_list
            
    except Exception:
        traceback.print_exc()
        return None
    
async def set_clanRecord_params():
    return

async def search_accountId(str):
    try:
        match = re.search(r"/player/(.*?),",str)
        if match:
            return int(match.group(1).strip())
        else:
            return None
    except Exception:
        traceback.print_exc()
        return None
       
async def search_color(str):
    try:
        match = re.search(r"color:(.*?);",str)
        if match:
            return match.group(1).strip()
        else:
            return None
    except Exception:
        traceback.print_exc()
        return None

async def set_damageColor(type,value):
    try:
        if type == 'Destroyer':
            if not value or value < 33000:
                return color_data["Bad"]
            elif value < 40000:
                return color_data["Good"]
            elif value < 55000:
                return color_data["Great"]
            elif value < 64000:
                return color_data["Unicum"]
            else:
                return color_data["Super Unicum"]
        elif type == 'Cruiser':
            if not value or value < 47000:
                return color_data["Bad"]
            elif value < 55000:
                return color_data["Good"]
            elif value < 83000:
                return color_data["Great"]
            elif value < 95000:
                return color_data["Unicum"]
            else:
                return color_data["Super Unicum"]
        elif type == 'AirCarrier':
            if not value or value < 60000:
                return color_data["Bad"]
            elif value < 71000:
                return color_data["Good"]
            elif value < 84000:
                return color_data["Great"]
            elif value < 113000:
                return color_data["Unicum"]
            else:
                return color_data["Super Unicum"]
        else:
            if not value or value < 64000:
                return color_data["Bad"]
            elif value < 72000:
                return color_data["Good"]
            elif value < 97000:
                return color_data["Great"]
            elif value < 108000:
                return color_data["Unicum"]
            else:
                return color_data["Super Unicum"]
    except Exception:
        traceback.print_exc()
        return None

async def set_winColor(value):
    try:
        if not value or value < 45:
            return color_data["Bad"]
        elif value < 50:
            return color_data["Below Average"]
        elif value < 55:
            return color_data["Average"]
        elif value < 60:
            return color_data["Good"]
        elif value < 65:
            return color_data["Great"]
        elif value < 70:
            return color_data["Unicum"]
        else:
            return color_data["Super Unicum"]
    except Exception:
        traceback.print_exc()
        return None

async def set_upinfo_color(value):
    try:
        if not value or value < 0 :
            return color_data["Bad"]
        elif value > 0 :
            return color_data["Good"]
        else:
            return None
    except Exception:
        traceback.print_exc()
        return None


from typing import List
import httpx
import traceback
import jinja2
import re
from datetime import datetime
from pathlib import Path
from .data_source import servers,set_recentparams
from .utils import match_keywords
from nonebot_plugin_htmlrender import html_to_pic
from .publicAPI import get_AccountIdByName
from nonebot import get_driver
from nonebot.log import logger
from httpx import ConnectTimeout
from asyncio.exceptions import TimeoutError

dir_path = Path(__file__).parent
template_path = dir_path / "template"
env = jinja2.Environment(
    loader=jinja2.FileSystemLoader(template_path), enable_async=True
)

headers = {
    'Authorization': get_driver().config.api_token
}


async def get_RecentInfo(server_type,qqid,info):
    try:
        params,day = None,0
        if datetime.now().hour < 7:
            day = 1
        if isinstance(info,List):
            for i in info:              #查找日期,没找到默认一天
                if str(i).isdigit() and len(i) <= 3:
                    day = str(i)
                    info.remove(i)
            for i in info:              #是否包含me或@，包含则调用平台接口
                if i == 'me':
                    params = {
                    "server": server_type,
                    "accountId": int(qqid),
                    "day": day,
                    "status": 0
                    }
                match = re.search(r"CQ:at,qq=(\d+)",i)
                if match:
                    params = {
                    "server": server_type,
                    "accountId": int(match.group(1)),
                    "day": day,
                    "status": 0
                    }
                    break
            if not params and len(info) == 2:
                param_server,info = await match_keywords(info,servers)
                if param_server:
                    param_accountid = await get_AccountIdByName(param_server,str(info[0]))
                    if isinstance(param_accountid,int):
                        params = {
                        "server": param_server,
                        "accountId": param_accountid,
                        "day": day,
                        "status": 0
                        }
                    else:
                        return f"{param_accountid}"
                else:
                    return '服务器参数似乎输错了呢'
            elif params:
                pass
            else:
                return '您似乎准备用游戏昵称查询水表，请检查参数中是否包含服务器和游戏昵称，以空格区分'
        else:
            return '参数似乎出了问题呢'
        url = 'https://api.wows.shinoaki.com//api/wows/recent/v2/recent/info'
        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
        async with httpx.AsyncClient(headers=headers) as client:
            resp = await client.get(url, params=params, timeout=None)
            result = resp.json()
            logger.info(f"本次请求返回的状态码:{result['code']}")
        if result['code'] == 200:
            if result['data']['shipData'][0]['shipData']:
                template = env.get_template("wws-info-recent.html")
                template_data = await set_recentparams(result['data'])
                content = await template.render_async(template_data)
                return await html_to_pic(content, wait=0, viewport={"width": 1200, "height": 100}) 
            else:
                return '该日期数据记录不存在'
        elif result['code'] == 403:
            return f"{result['message']}\n请先绑定账号"
        elif result['code'] == 404 or result['code'] == 405:
            return f"{result['message']}\n您可以发送wws help查看recent相关说明"
        elif result['code'] == 500:
            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
        else:
            return f"{result['message']}"
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'
    except Exception:
        logger.warning(traceback.format_exc())
        return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'